Learn R Programming

survBootOutliers (version 1.0)

get.whas100.dataset: Function that retrieves the WHAS100 dataset.

Description

This function retrieves the well known Worcester Heart Attack dataset with 100 individuals (WHAS100). This dataset is taken from the book by Hosmer D, Lemeshow S, May S. Applied Survival Analysis: Regression Modeling of Time to Event Data, 2nd edition. John Wiley and Sons Inc., New York, NY, 2008.

Usage

get.whas100.dataset()

Arguments

Value

A data.frame containing the WHAS100 dataset

Examples

Run this code
# NOT RUN {
whas100_data <- get.whas100.dataset()
# }

Run the code above in your browser using DataLab